/* util.VideoDisplay is Philippe's unmodified VideoDisplay.as Class from the flashdevelop sample forums
 *  http://www.flashdevelop.org/community/viewtopic.php?p=1583
 *  I built this preloader based off of his generous "Streaming FLV videos" example
 */
import VideoDisplay;

class Preeloader extends MovieClip
{
	// In reference from the MTASC tutorial
	// http://www.mtasc.org/#tutorial
	static var application : Preeloader;

	// The text field that holds the loaded percentage
	var LoadPercentage:TextField;
	// The number that will be used to invoke and run our interval for checking the 
	// NetStreams loaded status (How much of the flv is loaded)
	var interval_ID:Number;
	// The object which will hold the outline of the progress bar.  We must declare this in this scope so that
	// we will be able to access it from our function that checks the status of the loaded flv
	var Prog_Outline:Object;
	// The object which will hold the fully loaded progress bar.  We must declare this in this scope so that
	// we will be able to access it from our function that checks the status of the loaded flv
	var Prog_Full:Object;
    // The name of the flv file to be played.  This is used later on in order to determine the size of the video too
    var FLVName:String
	
	/* Despite the fact that this is the constructor for our class, MTASC will still use the 
	 *  static main function as the entry point.  Actually doing everything inside here.
	 *  Take special note, that we have assimilated _root into the Preeloader in order to allow
	 *  us to access it using "this" instead of _root.  This is described a little more on Aral Balkans blog
	 *  at http://aralbalkan.com/360?more=1&c=1
	 * 
	 *  If you don't do this, it makes it harder to register event listeners later on.
	 */
	function Preeloader( target ) {
		// Assimilating root
		   target.__proto__ = this.__proto__;
		   target.__constructor__ = Preeloader;
		   this = target;
		
		// Set the name of the flv you want played here
		FLVName = "FLVExample";
		
	    // Load the flv on layer 0
		var display:VideoDisplay = new VideoDisplay(null, this, "display", 0);
		display.setLocation(0, 0);
		display.setSize(Stage.width, Stage.height);
		// Pause the stream immediately after playing.  Firefox ignores Netstream.setBufferTime so we will only
		// start playing the stream again, once it is 100% loaded (see CheckLoadedPercentage )
		if(FLVName != "") {
		   display.play(FLVName + ".flv", 15);
		   display.stream.pause(true);
	    }
		
		// Load the percentage load bar outline on top of that on layer 1
		Prog_Outline = this.attachMovie("Progress_Outline", "Prog_Outline", 1, Prog_Outline);
		// Setting the empty load bar at perfect center based on its own width and height
		Prog_Outline._x =  (Stage.width / 2) - (Prog_Outline._width/2);
		Prog_Outline._y = (Stage.height / 2) - (Prog_Outline._height/2);
		
		// Load the percentage completed load bar on top of that on layer 2
		Prog_Full = this.attachMovie("Progress_Full", "Prog_Full", 2, Prog_Full);
		// Setting the full load bar directly on top of the load bar outline, but deliberately set its width to 0
		Prog_Full._x =  (Stage.width / 2) - (Prog_Full._width/2);
		Prog_Full._y = (Stage.height / 2) - (Prog_Full._height / 2);
		// Set the xscale of the full load bar to zero so it doesnt cover any of the outline bar
		Prog_Full._xscale = 0;
		
	    // Set the percentage on top of that on layer 3
		// First create a text format for it to make it the same color as the load bar
		var LoadTextFormat = new TextFormat("Arial", 10,0xFFFAF0,true);
		
		// Create the text field and put it at the same x location as the load bar, then directly underneath the calculated
		// position of the load bar
		createTextField("LoadPercentage", 3,Prog_Outline._x, (Prog_Outline._y + Prog_Outline._height), Stage.width, 25);
		LoadPercentage.setNewTextFormat( LoadTextFormat );
		LoadPercentage.text = 0 + "%";

		// Interval at which we will check the loaded state (500ms)
		// Will NOT WORK UNLESS YOU PASS "this"
        interval_ID = setInterval(this,"CheckLoadedPercentage", 500,display.stream); 

	}	
	/* This function is called every 500ms in order to check and adjust the percentage loaded number
	 * and the percentage loaded bar.  Once the percentage loaded is 100 or more, this clears the
	 * 500 ms interval so it isn't called anymore.  It also removes the progress bar and text from the stage
	 * */
	public function CheckLoadedPercentage(TheStream:NetStream) {
	// A variable that contains the video size in bytes.  Putting this in here makes it so we don't have to fool
	// with loading external xml or another file which is another big headache when using this method.
	   var VideoSize = 289354;
	   
	   var pctLoaded:Number = Math.round(TheStream.bytesLoaded / VideoSize * 100);
	   
	   // Update the percentage loaded number
	   LoadPercentage.text = pctLoaded + "%";
	   
	   // Now extend the Progress_Full bar in order to stretch to the percent loaded
	   Prog_Full._xscale = pctLoaded;
	   
	   if (pctLoaded >= 100 ) {
		 // We are 100% loaded, stop calling this function, and remove the load bar and percentage, unpause the flv
		 LoadPercentage.text = "";
		 Prog_Outline.removeMovieClip();
		 Prog_Full.removeMovieClip();
		 TheStream.pause(false);
	     clearInterval(interval_ID);
	   } else {
		 TheStream.pause(true);
	   }
	}
	
	/*  
	 * This is the entry point for the application.  If we don't use the application = new Preeloader
	 * statement, then you have problems with using other variables and calling functions outside of a
	 * static context which is very annoying.  It will also cause problems with setInterval for checking
	 * the load status of the video
	 * */
	static function main()
	{	
		application = new Preeloader( _root );
	}

}
